@@ -2,19 +2,20 @@ package Fennec::Util::Abstract;
 use strict;
 use warnings;
 
-use base 'Fennec::Base';
 use Carp;
 
-sub alias {
+sub import {
     my $class = shift;
-    my ($caller) = @{ shift(@_) };
-    for my $accessor ( @_ ) {
-        my $sub = sub {
-            die( "$caller does not implement $accessor()" );
-        };
-        no strict 'refs';
-        *{ $caller . '::' . $accessor } = $sub;
-    }
+    my $caller = caller;
+
+    no strict 'refs';
+    *{ $caller . '::Abstract' } = sub {
+        for my $accessor ( @_ ) {
+            *{ $caller . '::' . $accessor } = sub {
+                die( "$caller does not implement $accessor()" );
+            };
+        }
+    };
 }
 
 1;
